@@ -1,28 +1,21 @@
-##############################################################################
-#
-# Copyright (c) 2007 gocept gmbh & co. kg and Contributors.
-# All Rights Reserved.
-#
-# This software is subject to the provisions of the Zope Public License,
-# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
-# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
-# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE.
-#
-##############################################################################
+# Copyright (c) 2007-2010 gocept gmbh & co. kg
+# See also LICENSE.txt
 
 import os
 import os.path
 import urlparse
 import urllib
-import md5
 import tempfile
 import subprocess
 import shutil
 
 import zc.buildout.easy_install
 
+try:
+    from hashlib import md5
+except ImportError:
+    from md5 import new as md5
+
 
 class Recipe:
     """Recipe that downloads a package from the net and unpacks it.
@@ -179,8 +172,8 @@ class Recipe:
 
 
 def compute_md5sum(filename):
-    hash = md5.new('')
-    f = file(filename)
+    hash = md5('')
+    f = open(filename, 'rb')
     chunk = f.read(2**16)
     while chunk:
         hash.update(chunk)
